<?php

/**
 * @file
 * Contains \Drupal\redirect_page_by_role\EnablerService
 */

namespace Drupal\redirect_page_by_role\Service;

use Drupal\Core\Database\Database;
use Drupal\node\Entity\Node;

/**
 * Defines a service for managing RSVP list enabled for nodes.
 */
class EnablerService {

  /**
   * Constructor.
   */
  public function __construct() {
  }

  /**
   * Sets a individual node to have redirection rules enabled.
   *
   * @param Node $node
   */
  public function setEnabled(Node $node) {
    if (!$this->isEnabled($node)) {
      $insert = Database::getConnection()->insert('redirect_page_by_role_enabled');
      $insert->fields(['nid'], [$node->id()]);
      $insert->execute();
    }
  }

  /**
   * Checks if an individual node has redirection rules enabled.
   *
   * @param Node $node
   *
   * @return bool
   *   Return TRUE if redirection rules is enabled.
   */
  public function isEnabled(Node $node) {
    if ($node->isNew()) {
      return FALSE;
    }
    $select = Database::getConnection()->select('redirect_page_by_role_enabled', 're');
    $select->fields('re', ['nid']);
    $select->condition('nid', $node->id());
    $results = $select->execute();
    return !empty($results->fetchCol());
  }

  /**
   * Deletes enabled settings for an individual node.
   *
   * @param Node $node
   */
  public function delEnabled(Node $node) {
    $delete = Database::getConnection()->delete('redirect_page_by_role_enabled');
    $delete->condition('nid', $node->id());
    $delete->execute();
  }

}
